/*===================================================================*/
/*           Program setting for TLCS-900/H2  [ SAMPLE ]             */
/*                    (On-chip Hardware setting)                     */
/*                           [TMP94FD53]                             */
/*                          Revision: 1.00                           */
/*  This program is examples of program for TMP94FD53.               */
/*  When you use this sample program, you must rewrite to fit your   */
/*  system. And please confirm that there is no mistake about        */
/*  generated object code.                                           */
/*===================================================================*/
/*     Copyright(C) TOSHIBA CORPORATION 2001  All rights reserved    */
/*===================================================================*/
/*===================================================================*/
/*  [ File include part ]                                            */
/*===================================================================*/


/**********************************************************************
*
*       This file, originally deliverd by TOSHIBA, was modified
*       by SEGGER Microntroller Systeme GmbH
*       to be used with embOS:
*
*       1.  Call of __EI() before calling main was removed from
*           _Initial().
*
*       2.  External interrupt service routines used by embOS
*           declared
*
*       3.  Interrupt vector table was modified to be used 
*           with embOS
*
**********************************************************************/

#include    "io900h2.h"   /* for the reference of I/O */
#include    <stdlib.h>    /* for '__EI()','abort()' and 'exit()' */

/*===================================================================*/
/* [ Prototype of function definition part ]                         */
/*   This part is necessary for main function calling.               */
/*===================================================================*/
void    main(void);         /* For main function calling */

/*===================================================================*/
/* [ Sample of initialize and EI and call main ]                     */
/*   This function is jumped from start up routine in 'stc94ml.mac'. */
/*   Rewrite this part to fit your program.                          */
/*===================================================================*/

void    _Initial(void){
  /*==  Write your initialize routine.      ==*/

  /***** Modification 1: Call of __EI() commented out by SEGGER ******/
   
  /*===[ Interrupt enable ]==========================================*/
  /*  __EI();                                                 SAMPLE */

  /***** End of Modification 1 ***************************************/

  /*===[ Call main function ]========================================*/
  main();                                                    

  /*===[ Dummy Loop ]================================================*/
      for(;;);                                             /* SAMPLE */
}

/*===================================================================*/
/* [ Sample of interrupt function ]                                  */
/*   Make interrupt routine to fit your program.                     */
/*===================================================================*/
/*===[ Sample for interrupt :                               ]========*/
/*===[       This function has only one instruction 'RETI'  ]========*/
void __interrupt _Int_dummy(void){
}


/***** Modification 2: external ISR declared by SEGGER ***************/

/**********************************************************************
*
*       Interface to embOS
*
*       definition of external interrupt service routines
*       used by embOS
*
***********************************************************************
*/

#ifndef OS_TIMER
  #define OS_TIMER 8               /* Use 16 bit Timer 8 per default */
#else
  #if (OS_TIMER != 1) && (OS_TIMER != 8)
    #error "Timer not supported by current version of embOS."
  #endif  
#endif
  
void __interrupt OS_ISR_Tick(void);    /*  embOS timer tick          */
void __interrupt OS_ISR_Rx(void);      /*  Rx ISR for embOSView      */
void __interrupt OS_ISR_Tx(void);      /*  Tx ISR for embOSView      */
void __interrupt OSTEST_X_ISR0(void);  /*  Segger internal test,     */
                                       /*  may be removed            */

/***** End of Modification 2 *****************************************/


/*===================================================================*/
/* [ Define interrupt table ]                                        */
/*   Rewrite the base address of interrupt table to fit your target  */
/*   MCU. Write interrupt functions name you made, as initializer    */
/*   of table.                                                       */
/*===================================================================*/
#define  _SecInt_Name  inttbl     /* Section name of interrupt table */
#define  _BaseIntTbl   0xFFFF00      /* Interrupt table base address */
#define  _SecInt_Attr  const /* Section attribute of interrupt table */
void     _startup(void);    /* Prototype definition for reset vector */
                      /* This function is defined in a 'stc94ml.mac' */

#pragma  section  _SecInt_Attr  _SecInt_Name  _BaseIntTbl

/***** Modification 3: embOS interrupt vectors added by SEGGER *******/

void * const _IntTbl[] = {
           _startup         /* Reset/SWI 0    */
          ,_Int_dummy       /* SWI 1          */
          ,_Int_dummy       /* INTUNDEF/SWI 2 */
          ,_Int_dummy       /* SWI 3          */
          ,_Int_dummy       /* SWI 4          */
          ,_Int_dummy       /* SWI 5          */
          ,_Int_dummy       /* SWI 6          */
          ,_Int_dummy       /* SWI 7          */
          ,_Int_dummy       /* NMI            */
          ,_Int_dummy       /* INTWD          */
          ,_Int_dummy       /* INT0           */
          ,_Int_dummy       /* INT1           */
          ,_Int_dummy       /* INT2           */
          ,_Int_dummy       /* INT3           */
          ,_Int_dummy       /* INT4           */
          ,_Int_dummy       /* INT5           */
          ,_Int_dummy       /* INT6           */
          ,_Int_dummy       /* INT7           */
          ,_Int_dummy       /* INTT0          */
#if (OS_TIMER == 1)
          ,OS_ISR_Tick      /* INTT1, embOS tick interrupt */
#else
          ,_Int_dummy       /* INTT2          */
#endif
          ,_Int_dummy       /* INTT2          */
          ,_Int_dummy       /* INTT3          */
          ,_Int_dummy       /* INTT4          */
          ,_Int_dummy       /* INTT5          */
          ,_Int_dummy       /* INTT6          */
          ,_Int_dummy       /* INTT7          */
          ,_Int_dummy       /* INTTR8         */
#if (OS_TIMER == 8)
          ,OS_ISR_Tick      /* INTTR9, embOS tick interrupt */
#else
          ,_Int_dummy       /* INTTR9         */
#endif          
          ,_Int_dummy       /* INTTRA         */
#ifdef OS_TEST
          ,OSTEST_X_ISR0    /* INTTRB, Segger internal test, may be removed*/
#else
          ,_Int_dummy       /* INTTRB         */
#endif
          ,_Int_dummy       /* INTTO8         */
          ,_Int_dummy       /* INTTOA         */
          
/*  The following 4 interrupt vectors are defined for embOSView  */
/*  If embOSView should not be used, modify these vectors  e     */

          ,OS_ISR_Rx        /* INTRX0, for embOSView only        */
          ,OS_ISR_Tx        /* INTTX0         */
          ,OS_ISR_Rx        /* INTRX1         */
          ,OS_ISR_Tx        /* INTTX1         */
          ,_Int_dummy       /* INTCR          */
          ,_Int_dummy       /* INTCT          */
          ,_Int_dummy       /* INTCG          */
          ,_Int_dummy       /* INTSEM0        */
          ,_Int_dummy       /* INTSEE0        */
          ,_Int_dummy       /* INTSER0        */
          ,_Int_dummy       /* INTSET0        */
          ,_Int_dummy       /* INTSEM1        */
          ,_Int_dummy       /* INTSEE1        */
          ,_Int_dummy       /* INTSER1        */
          ,_Int_dummy       /* INTSET1        */
          ,_Int_dummy       /* INTSBE0        */
          ,_Int_dummy       /* INTSBS0        */
          ,_Int_dummy       /* INTSBE1        */
          ,_Int_dummy       /* INTSBS1        */
          ,_Int_dummy       /* INTAD          */
          ,_Int_dummy       /* INTTC0         */
          ,_Int_dummy       /* INTTC1         */
          ,_Int_dummy       /* INTTC2         */
          ,_Int_dummy       /* INTTC3         */
          ,_Int_dummy       /* INTTC4         */
          ,_Int_dummy       /* INTTC5         */
          ,_Int_dummy       /* INTTC6         */
          ,_Int_dummy       /* INTTC7         */
    };

#pragma  section  _SecInt_Attr

/***** End of Modification 3 *****************************************/


/*===================================================================*/
/*   Standard C Library setting for TLCS-900/H2  [ SAMPLE ]          */
/*                           [TMP94FD53]                             */
/*                          Revision: 1.00                           */
/*===================================================================*/
/*===================================================================*/
/* [ Configuration part ]                                            */
/*   Following macro value means that:                               */
/*   0 : The function is not used.                                   */
/*   1 : The function is used.                                       */
/*   When you use 'abort' or 'exit' or 'heap area',                  */
/*   Rewrite each program to fit your use.                           */
/*===================================================================*/
#define  __USE_FLOAT    0   /* Change 0 to 1, if use floating point. */
#define  __USE_ABORT    0   /* Change 0 to 1, if use abort function. */
#define  __USE_EXIT     0   /* Change 0 to 1, if use exit function.  */
#define  __USE_HEAP     0   /* Change 0 to 1, if use heap area.      */

#if __USE_FLOAT
/*===================================================================*/
/* [ Define public variable ]                                        */
/*  When use floating point, this part is necessary.                 */
/*  Do not change this part.                                         */
/*  'errno' is reserved word. Do not access to this variable.        */
/*===================================================================*/
int     errno;                        /* Refer from standard library */

#endif      /* __USE_FLOAT */

#if __USE_ABORT
/*===================================================================*/
/* [ Standard library function: abort() ]                            */
/*   When use abort function, this part is necessary.                */
/*   Rewrite this part to fit your program.                          */
/*===================================================================*/
void    abort(void){
  /*=================================================================*/
  /*  Write the process before reset, then jump to your start up     */
  /*  routine.                                                       */
  /*=================================================================*/
  /*  __asm("    j    __startup");                            SAMPLE */
  /*=================================================================*/
}
#endif      /* __USE_ABORT */

#if __USE_EXIT
/*===================================================================*/
/* [ Standard library function: exit() ]                             */
/*   When use exit function, this part is necessary.                 */
/*   Rewrite this part to fit your program.                          */
/*===================================================================*/
void    exit(int status){
  /*=================================================================*/
  /*  Write the process as same as normal program ending.            */
  /*=================================================================*/
  /*  __asm("    halt");                                      SAMPLE */
  /*=================================================================*/
}
#endif      /* __USE_EXIT */

#if __USE_HEAP





#endif      /* __USE_HEAP */

/* End of file */
