/*****************************************************************
**		TLCS-900 C Compiler Header File			**
**--------------------------------------------------------------**
**	[For]		{TMP94FD53}				**
**	[File name]	{SIH.H}				    **
 *	[Subject]	{Mask pattern for Serial Channel}	*
**  Copyright(C) 2001 TOSHIBA CORPORATION All rights reserved	**
*****************************************************************/

/**********************************************
 *   SC0BUF/ SC1BUF (serial channel buffer)   *
 **********************************************/
#define	RB7		0x80	/* Serial channel buffer register bit 7 */
#define	RB6		0x40	/* Serial channel buffer register bit 6 */
#define	RB5		0x20	/* Serial channel buffer register bit 5 */
#define	RB4		0x10	/* Serial channel buffer register bit 4 */
#define	RB3		0x08	/* Serial channel buffer register bit 3 */
#define	RB2		0x04	/* Serial channel buffer register bit 2 */
#define	RB1		0x02	/* Serial channel buffer register bit 1 */
#define	RB0		0x01	/* Serial channel buffer register bit 0 */
#define	TB7		RB7		/* Serial channel buffer register bit 7 */
#define	TB6		RB6		/* Serial channel buffer register bit 6 */
#define	TB5		RB5		/* Serial channel buffer register bit 5 */
#define	TB4		RB4		/* Serial channel buffer register bit 4 */
#define	TB3		RB3		/* Serial channel buffer register bit 3 */
#define	TB2		RB2		/* Serial channel buffer register bit 2 */
#define	TB1		RB1		/* Serial channel buffer register bit 1 */
#define	TB0		RB0		/* Serial channel buffer register bit 0 */

/*******************************************
 *   SC0MOD0/SC1MOD0 (serial channel mode)   *
 *******************************************/
#define	TB8		0x80	/* bit-8 of sended data */
#define	CTSE	0x40	/* hand-shake;		0:CTS disable	1:CTS enable */
#define	RXE		0x20	/* receiving;		0:disable	1:enable */
#define	WU		0x10	/* wake up mode		0:disable	1:enable */
#define	SM1		0x08	/*---transmit mode---*/
#define	SM0		0x04	/*---transmit mode---*/
#define	SM		0x0c	/*---transmit mode(SM1,SM0)---
				 	00:I/O interface
				 	01:UART 7bit
				 	10:UART 8bit
				 	11:UART 9bit		*/
#define	SC1		0x02	/*---source clock---*/
#define	SC0		0x01	/*---source clock---*/
#define	SC		0x03	/*---source clock(SC1,SC0)---
					00:T0 trigger
					01:Baud rate generator
					10:internal clock $1
					11:external clock SCLK	*/

/********************************************
 *   SC0CR/SC1CR (serial channel control)   *
 ********************************************/
#define	RB8			0x80	/* bit-8 of received data  */
#define	EVEN		0x40	/* parity mode;		0:odd      1:even */
#define	PE			0x20	/* parity;		0:disable  1:enable */
#define	PARITY		0x60	/* EVEN, PE bit mask pattern */
#define	OERR		0x10	/* overrun bit  1:error */
#define	PERR		0x08	/* parity  bit  1:error */
#define	FERR		0x04	/* flaming bit  1:error */
#define	SRERR		0x1c	/* OERR, PERR, FERR Serial error bit mask pattern */
#define	SCLKS		0x02	/* latch timming of I/O interface
					0:edge of SCLK0 _|~
					1:edge of SCLK0 ~|_		*/
#define	IOC		0x01	/* source clock of I/O interface
					0:baud rate generator
					1:SCLK		*/

/*********************************
 *   BR0CR (baud rate control)   *
 *********************************/
#define	BR0ADDE		0x40	/* (16-K)/16  0:Disable 1:Enable */
#define	BR0CK1		0x20	/*--source clock---*/
#define	BR0CK0		0x10	/*--source clock---*/
#define	BR0CK		0x30	/*--source clock---
					00:$T0  (4/fc)
					01:$T2  (16/fc)
					10:$T8  (64/fc)
					11:$T32 (256/fc)		*/
#define	BR0S3		0x08	/* scale register of baud rate; bit3 */
#define	BR0S2		0x04	/* scale register of baud rate; bit2 */
#define	BR0S1		0x02	/* scale register of baud rate; bit1 */
#define	BR0S0		0x01	/* scale register of baud rate; bit0 */
#define	BR0S		0x0F	/* set of the Divided freuency */

/*********************************
 *   BR1CR (baud rate control)   *
 *********************************/
#define	BR1ADDE		0x40	/* (16-K)/16 0:Disable 1:Enable */
#define	BR1CK1		0x20	/*--source clock---*/
#define	BR1CK0		0x10	/*--source clock---*/
#define	BR1CK		0x30	/*--source clock---
					00:$T0  (4/fc)
					01:$T2  (16/fc)
					10:$T8  (64/fc)
					11:$T32 (256/fc)		*/
#define	BR1S3		0x08	/* scale register of baud rate; bit3 */
#define	BR1S2		0x04	/* scale register of baud rate; bit2 */
#define	BR1S1		0x02	/* scale register of baud rate; bit1 */
#define	BR1S0		0x01	/* scale register of baud rate; bit0 */
#define	BR1S		0x0f	/* set of the Divided freuency */

/****************************************
 *   BR0ADD                             *
 ****************************************/
#define	BR0K3		0x08	
#define	BR0K2		0x04	
#define	BR0K1		0x02	
#define	BR0K0		0x01	
#define	BR0K		0x0F	

/****************************************
 *   BR1ADD                             *
 ****************************************/
#define	BR1K3		0x08	
#define	BR1K2		0x04	
#define	BR1K1		0x02	
#define	BR1K0		0x01	
#define	BR1K		0x0F	


/*******************************************
 *   SC0MOD1 (Sirial Mode Contorol Register)
 *******************************************/
#define	I2S0		0x80	/* IDLE2 */
#define FDPX0		0x40	

/*******************************************
 *   SC1MOD1 (Sirial Mode Contorol Register)
 *******************************************/
#define	I2S1		0x80	/* IDLE2 */
#define FDPX1		0x40	


/*-eof-*/
